# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class YodaIoPreferentialTierEnum(object):

    """Implementation of the 'YodaIoPreferentialTier' enum.
    Specifies the list of perferred storage tiers used by Yoda.


    Attributes:
        KPCIESSD: TODO: type description here.
        KSATASSD: TODO: type description here.
        KSATAHDD: TODO: type description here.
        KCLOUD: TODO: type description here.

    """

    KPCIESSD = 'kPcieSsd'

    KSATASSD = 'kSataSsd'

    KSATAHDD = 'kSataHdd'

    KCLOUD = 'kCloud'
